==> webgui_7.10.23.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/PayDriver.pm <==
package WebGUI::i18n::Dutch::PayDriver;
use utf8;
our $I18N = {
  'a sale has been made' => {
    'lastUpdated' => '1239870803',
    'message' => 'Er is een aankoop gedaan. Bestelling #'
  },
  'cart summary variables' => {
    'lastUpdated' => '1273495572',
    'message' => 'Winkelwagensamenvatting variabelen'
  },
  'cart summary variables help' => {
    'lastUpdated' => '1273497334',
    'message' => 'Deze variabelen moeten beschikbaar zijn in alle sjablonen van betalingsmethoden, zodat de samenvatiing van de winkelwagen aan de gebruiker getoond kan worden.'
  },
  'credit card' => {
    'lastUpdated' => '1216587041',
    'message' => 'Creditcard'
  },
  'email receipt template' => {
    'lastUpdated' => '1213880142',
    'message' => 'E-mail ontvangstbewijs sjabloon'
  },
  'email receipt template help' => {
    'lastUpdated' => '1213880177',
    'message' => 'Dit sjabloon wordt gebruikt voor ontvangstbewijzen die per e-mail aan de gebruiker worden gestuurd.'
  },
  'enabled' => {
    'lastUpdated' => '1213880332',
    'message' => 'Aangezet'
  },
  'enabled help' => {
    'lastUpdated' => '1213880363',
    'message' => 'Hier wordt ingesteld of deze betalingsmethode is aangezet.'
  },
  'error processing payment' => {
    'lastUpdated' => '1213880387',
    'message' => 'Fout bij verwerken betaling'
  },
  'error processing payment message' => {
    'lastUpdated' => '1213880600',
    'message' => 'Er is een fout opgetreden bij het verwerken van de betaling. Vaak zijn typfouten de oorzaak. Er kan echter ook een verbindingsprobleem zijn of er staat niet genoeg geld op de rekening om deze transactie te voltooien. Hieronder staat de door ons ontvangen foutmelding. Gebruik de terug knop van de browser om terug te gaan en vergissingen te corrigeren. Als het probleem blijft bestaan, neem dan contact met ons op'
  },
  'label' => {
    'lastUpdated' => '1213880606',
    'message' => 'Label'
  },
  'label help' => {
    'lastUpdated' => '1216587062',
    'message' => 'De naam waarmee een betalingsmethode getoond wordt in het scherm met de betalingsmethoden.'
  },
  'payment methods' => {
    'lastUpdated' => '1213880915',
    'message' => 'Betalingsmethoden'
  },
  'proceedButton' => {
    'lastUpdated' => '1273495692',
    'message' => 'Een gecombineerde knop met formulier waar de gebruiker op kan drukken wanneer ze de kosten van de betalingsmethode hebben kunnen bekijken.'
  },
  'receipt email template' => {
    'lastUpdated' => '1213880941',
    'message' => 'Sjaboon voor e-mail ontvangstbewijs'
  },
  'receipt email template help' => {
    'lastUpdated' => '1213880991',
    'message' => 'Welk sjabloon moet gebruikt worden voor het genereren van een e-mail die naar de gebruikers gestuurd wordt om hun aankopen te bevestigen?'
  },
  'receipt subject' => {
    'lastUpdated' => '1213880124',
    'message' => 'Ontvangstbewijs voor bestelling #'
  },
  'sale notification group' => {
    'lastUpdated' => '1213880245',
    'message' => 'Verkoop notificatie groep'
  },
  'sale notification group help' => {
    'lastUpdated' => '1213881010',
    'message' => 'Wie moet ingelicht worden bij nieuwe transacties?'
  },
  'template gone' => {
    'lastUpdated' => '1273488753',
    'message' => 'Het sjabloon voor het invoeren van de gegevens is verwijderd. Informeer altublieft de beheerder.'
  },
  'try again' => {
    'lastUpdated' => '1218985952',
    'message' => 'Ga terug om het opnieuw te proberen.'
  },
  'who can use' => {
    'lastUpdated' => '1213879757',
    'message' => 'Groep die deze methode kan gebruiken'
  },
  'who can use help' => {
    'lastUpdated' => '1213879740',
    'message' => 'Hier wordt gespecificeerd welke group deze betalingsmethode mag gebruiken.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/PayDriver.pm <==
package WebGUI::i18n::Dutch::PayDriver;
use utf8;
our $I18N = {
  'a sale has been made' => {
    'lastUpdated' => '1239870803',
    'message' => 'Er is een aankoop gedaan. Bestelling #'
  },
  'cart summary variables' => {
    'lastUpdated' => '1273495572',
    'message' => 'Winkelwagensamenvatting variabelen'
  },
  'cart summary variables help' => {
    'lastUpdated' => '1273497334',
    'message' => 'Deze variabelen moeten beschikbaar zijn in alle sjablonen van betalingsmethoden, zodat de samenvatiing van de winkelwagen aan de gebruiker getoond kan worden.'
  },
  'credit card' => {
    'lastUpdated' => '1216587041',
    'message' => 'Creditcard'
  },
  'email receipt template' => {
    'lastUpdated' => '1213880142',
    'message' => 'E-mail ontvangstbewijs sjabloon'
  },
  'email receipt template help' => {
    'lastUpdated' => '1213880177',
    'message' => 'Dit sjabloon wordt gebruikt voor ontvangstbewijzen die per e-mail aan de gebruiker worden gestuurd.'
  },
  'enabled' => {
    'lastUpdated' => '1213880332',
    'message' => 'Aangezet'
  },
  'enabled help' => {
    'lastUpdated' => '1213880363',
    'message' => 'Hier wordt ingesteld of deze betalingsmethode is aangezet.'
  },
  'error processing payment' => {
    'lastUpdated' => '1213880387',
    'message' => 'Fout bij verwerken betaling'
  },
  'error processing payment message' => {
    'lastUpdated' => '1213880600',
    'message' => 'Er is een fout opgetreden bij het verwerken van de betaling. Vaak zijn typfouten de oorzaak. Er kan echter ook een verbindingsprobleem zijn of er staat niet genoeg geld op de rekening om deze transactie te voltooien. Hieronder staat de door ons ontvangen foutmelding. Gebruik de terug knop van de browser om terug te gaan en vergissingen te corrigeren. Als het probleem blijft bestaan, neem dan contact met ons op'
  },
  'label' => {
    'lastUpdated' => '1213880606',
    'message' => 'Label'
  },
  'label help' => {
    'lastUpdated' => '1216587062',
    'message' => 'De naam waarmee een betalingsmethode getoond wordt in het scherm met de betalingsmethoden.'
  },
  'payment methods' => {
    'lastUpdated' => '1213880915',
    'message' => 'Betalingsmethoden'
  },
  'proceedButton' => {
    'lastUpdated' => '1273495692',
    'message' => 'Een gecombineerde knop met formulier waar de gebruiker op kan drukken wanneer ze de kosten van de betalingsmethode hebben kunnen bekijken.'
  },
  'receipt email template' => {
    'lastUpdated' => '1213880941',
    'message' => 'Sjaboon voor e-mail ontvangstbewijs'
  },
  'receipt email template help' => {
    'lastUpdated' => '1213880991',
    'message' => 'Welk sjabloon moet gebruikt worden voor het genereren van een e-mail die naar de gebruikers gestuurd wordt om hun aankopen te bevestigen?'
  },
  'receipt subject' => {
    'lastUpdated' => '1213880124',
    'message' => 'Ontvangstbewijs voor bestelling #'
  },
  'sale notification group' => {
    'lastUpdated' => '1213880245',
    'message' => 'Verkoop notificatie groep'
  },
  'sale notification group help' => {
    'lastUpdated' => '1213881010',
    'message' => 'Wie moet ingelicht worden bij nieuwe transacties?'
  },
  'template gone' => {
    'lastUpdated' => '1273488753',
    'message' => 'Het sjabloon voor het invoeren van de gegevens is verwijderd. Informeer altublieft de beheerder.'
  },
  'try again' => {
    'lastUpdated' => '1218985952',
    'message' => 'Ga terug om het opnieuw te proberen.'
  },
  'unable to finish transaction' => {
    'lastUpdated' => '1311780390',
    'message' => 'Helaas kon de transactie niet worden gecontroleerd, waardoor de betaling nog niet afgerond is.'
  },
  'who can use' => {
    'lastUpdated' => '1213879757',
    'message' => 'Groep die deze methode kan gebruiken'
  },
  'who can use help' => {
    'lastUpdated' => '1213879740',
    'message' => 'Hier wordt gespecificeerd welke group deze betalingsmethode mag gebruiken.'
  }
}
;

1;
